@@ -14,12 +14,12 @@
 #    under the License.
 #
 import unittest
+from unittest import mock
+from urllib import parse as urlparse
 
-import mock
 from requests import codes
 from requests import exceptions as requests_exceptions
 from requests import models
-import six.moves.urllib.parse as urlparse
 
 from oslo_serialization import jsonutils
 
@@ -546,3 +546,11 @@ class ClusteredAPITestCase(nsxlib_testcase.NsxClientTestCase):
             api = self.mock_nsx_clustered_api()
             # just make sure this api is defined, and does not crash
             api._reinit_cluster()
+
+    def test_initialize_cluster_without_health_check(self):
+        conf_managers = ['8.9.10.11', '9.10.11.12']
+        validate_fn = mock.MagicMock()
+        api = self.new_mocked_cluster(conf_managers, validate_fn,
+                                      enable_health_check=False)
+        self.assertEqual(cluster.ClusterHealth.GREEN, api.health)
+        validate_fn.assert_not_called()
