@@ -15,7 +15,6 @@
 #
 
 from oslo_utils import excutils
-import six
 
 from vmware_nsxlib._i18n import _
 
@@ -40,10 +39,6 @@ class NsxLibException(Exception):
                     # at least get the core message out if something happened
                     super(NsxLibException, self).__init__(self.message)
 
-    if six.PY2:
-        def __unicode__(self):
-            return unicode(self.msg) if six.PY2 else self.msg  # noqa
-
     def __str__(self):
         return self.msg
 
@@ -75,6 +70,7 @@ class ManagerError(NsxLibException):
     message = _("Unexpected error from backend manager (%(manager)s) "
                 "for %(operation)s%(details)s")
     related_error_codes = []
+    related_status_codes = []
 
     def __init__(self, **kwargs):
         details = kwargs.get('details', '')
@@ -87,6 +83,7 @@ class ManagerError(NsxLibException):
         self.error_code = kwargs.get('error_code')
         self.related_error_codes = kwargs.get('related_error_codes', [])
         self.status_code = kwargs.get('status_code')
+        self.related_status_codes = kwargs.get('related_status_codes', [])
 
 
 class ResourceNotFound(ManagerError):
@@ -94,6 +91,11 @@ class ResourceNotFound(ManagerError):
                 "%(operation)s")
 
 
+class MultipleResourcesFound(ManagerError):
+    message = _("Multiple resources are found on backend (%(manager)s) for "
+                "%(operation)s, where only one is expected")
+
+
 class BackendResourceNotFound(ResourceNotFound):
     message = _("%(details)s On backend (%(manager)s) with Operation: "
                 "%(operation)s")
