@@ -75,6 +75,9 @@ TIER0_LOCALE_SERVICES_PATH_PATTERN = (TIER0S_PATH_PATTERN +
 TIER1_LOCALE_SERVICES_PATH_PATTERN = (TIER1S_PATH_PATTERN +
                                       "%s/locale-services/")
 
+OBJECT_PERMISSIONS_PATH_PATTERN = (TENANTS_PATH_PATTERN +
+                                   "object-permissions")
+
 
 class ResourceDef(object, metaclass=abc.ABCMeta):
     def __init__(self, nsx_version=None, **kwargs):
@@ -516,6 +519,7 @@ class RouterLocaleServiceDef(ResourceDef):
     def get_obj_dict(self):
         body = super(RouterLocaleServiceDef, self).get_obj_dict()
         self._set_attr_if_specified(body, 'edge_cluster_path')
+        self._set_attr_if_specified(body, 'preferred_edge_paths')
         return body
 
 
@@ -736,8 +740,17 @@ class RouterStaticRoute(ResourceDef):
 
         # next hops
         if self.has_attr('next_hop'):
+            next_hops = []
+            param_dict = dict()
             next_hop = self.get_attr('next_hop')
-            next_hops = [{'ip_address': next_hop}]
+            param_dict['ip_address'] = next_hop
+
+            # scope parameter
+            if self.has_attr('scope'):
+                scope_path = self.get_attr('scope')
+                param_dict['scope'] = [scope_path]
+
+            next_hops.append(param_dict)
             self._set_attr_if_specified(body, 'next_hop',
                                         body_attr='next_hops',
                                         value=next_hops)
@@ -2484,6 +2497,21 @@ class NsxPolicyApi(object):
     def partial_updates_supported(self):
         return self.partial_updates
 
+    def update_with_put(self, resource_def, revision=None):
+        """Create or update a policy object with PUT
+
+        During concurrent read-updates, using PUT can be safer as it requires
+        revision number in the object. Policy API rejects the request if
+        revision number is not latest
+        """
+        path = resource_def.get_resource_path()
+        if resource_def.resource_use_cache():
+            self.cache.remove(path)
+        body = resource_def.get_obj_dict()
+        if revision is not None:
+            body.update({"_revision": revision})
+        return self.client.update(path, body)
+
     def create_or_update(self, resource_def, partial_updates=False,
                          force=False):
         """Create or update a policy object.
@@ -2764,3 +2792,43 @@ class Tier0RouteRedistributionRule(object):
             body['route_map_path'] = self.route_map_path
 
         return body
+
+
+class ObjectRolePermissionGroupDef(ResourceDef):
+
+    @staticmethod
+    def resource_type():
+        return 'ObjectRolePermissionGroupDef'
+
+    # GET and DELETE accept query parameters in url, but PATCH url does not
+    # accept query parameters. path_prefix and role_name uniquely defines
+    # this resource on NSX
+    @property
+    def path_pattern(self):
+        path_prefix = self.get_attr('path_prefix')
+        role_name = self.get_attr('role_name')
+        if path_prefix and path_prefix.startswith('/'):
+            path_prefix = path_prefix[1:]
+        if not self.get_attr('patch') and (path_prefix or role_name):
+            url_query = utils.params_to_url_query(
+                path_prefix=path_prefix,
+                role_name=role_name
+            )
+            return OBJECT_PERMISSIONS_PATH_PATTERN + "?" + url_query
+        return OBJECT_PERMISSIONS_PATH_PATTERN
+
+    @property
+    def path_ids(self):
+        return ('tenant', 'dummy')
+
+    def get_obj_dict(self):
+        body = super(ObjectRolePermissionGroupDef, self).get_obj_dict()
+        self._set_attrs_if_specified(body, ['inheritance_disabled',
+                                            'operation',
+                                            'path_prefix',
+                                            'role_name',
+                                            'rule_disabled'])
+        obj_id = self.get_attr("orbac_id")
+        if obj_id:
+            body.update({"id": obj_id})
+        return body
